//
//  RegexHelpers.swift
//  iRegex
//
//  Created by James Frost on 14/10/2014.
//  Copyright (c) 2014 Razeware LLC. All rights reserved.
//

import Foundation

extension NSRegularExpression {
  
  convenience init?(options: SearchOptions) {
    let searchString = options.searchString
    let isCaseSensitive = options.matchCase
    let isWholeWords = options.wholeWords
    
    let regexOption: NSRegularExpressionOptions = (isCaseSensitive) ? .allZeros : .CaseInsensitive
    
    let pattern = (isWholeWords) ? "\\b\(searchString)\\b" : searchString
    
    self.init(pattern: pattern, options: regexOption, error: nil)
  }
  
  class func regularExpressionForDates() -> NSRegularExpression? {
    let pattern = "(\\d{1,2}[-/.]\\d{1,2}[-/.]\\d{1,2})|(Jan(uary)?|Feb(ruary)?|Mar(ch)?|Apr(il)?|May|Jun(e)?|Jul(y)?|Aug(ust)?|Sep(tember)?|Oct(ober)?|Nov(ember)?|Dec(ember)?)\\s*(\\d{1,2}(st|nd|rd|th)?+)?[,]\\s*\\d{4}"
    return NSRegularExpression(pattern: pattern, options: .CaseInsensitive, error: nil)
  }
  
  class func regularExpressionForTimes() -> NSRegularExpression? {
    let pattern = "\\d{1,2}\\s*(pm|am)"
    return NSRegularExpression(pattern: pattern, options: .CaseInsensitive, error: nil)
  }
  
  class func regularExpressionForLocations() -> NSRegularExpression? {
    let pattern = "[a-zA-Z]+[,]\\s*([A-Z]{2})"
    return NSRegularExpression(pattern: pattern, options: .allZeros, error: nil)
  }
  
}